@@ -2,9 +2,9 @@ from .const import ConnectionInfo, DoorStatus, LockInfo, LockState, LockStatus
 from .lock import Lock
 from .push import PushLock
 from .session import AuthError, DisconnectedError
-from .util import local_name_to_serial, serial_to_local_name
+from .util import ValidatedLockConfig, local_name_to_serial, serial_to_local_name
 
-__version__ = "0.17.1"
+__version__ = "0.18.0"
 
 __all__ = [
     "AuthError",
@@ -16,6 +16,7 @@ __all__ = [
     "LockState",
     "LockStatus",
     "PushLock",
+    "ValidatedLockConfig",
     "serial_to_local_name",
     "local_name_to_serial",
 ]
